@@ -1,6 +1,6 @@
 package App::JobLog::Log;
 {
-  $App::JobLog::Log::VERSION = '1.030';
+  $App::JobLog::Log::VERSION = '1.031';
 }
 
 # ABSTRACT: the code that lets us interact with the log
@@ -612,15 +612,21 @@ sub _scan_for_previous {
 
     # collect events
     my ( $previous, $previous_index );
-    for my $index ( $i .. $#$io ) {
-        my $line = $io->[$index];
-        my $ll   = App::JobLog::Log::Line->parse($line);
-        if ( $ll->is_endpoint ) {
-            $previous->end = $ll->time if $previous && $previous->is_open;
-            last if $ll->time > $e;
-            if ( $ll->is_beginning ) {
-                $previous       = App::JobLog::Log::Event->new($ll);
-                $previous_index = $index;
+  OUTER: {
+        for my $index ( $i .. $#$io ) {
+            my $line = $io->[$index];
+            my $ll   = App::JobLog::Log::Line->parse($line);
+            if ( $ll->is_endpoint ) {
+                $previous->end = $ll->time if $previous && $previous->is_open;
+                if ( $ll->time > $e ) {
+                    last if $previous;
+                    $i--;
+                    redo OUTER;
+                }
+                if ( $ll->is_beginning ) {
+                    $previous       = App::JobLog::Log::Event->new($ll);
+                    $previous_index = $index;
+                }
             }
         }
     }
@@ -807,7 +813,7 @@ App::JobLog::Log - the code that lets us interact with the log
 
 =head1 VERSION
 
-version 1.030
+version 1.031
 
 =head1 DESCRIPTION
 
